# CHANGELOG


## v0.2.1 (2025-02-03)

### Bug Fixes

- Actually use a directional variogram
  ([`ce9b37e`](https://github.com/gasflux/gasflux/commit/ce9b37eef1a9e3249110bb972294004ac1468fee))

- Add strategies to testconfig
  ([`6a620f2`](https://github.com/gasflux/gasflux/commit/6a620f2c0191446f542beeff5f3244764725051c))

- Automate build and PyPI deployment
  ([`84792cc`](https://github.com/gasflux/gasflux/commit/84792cc7e7473583727393e57d80758a2c12fda0))

- Automate build and PyPI deployment
  ([`d4aee57`](https://github.com/gasflux/gasflux/commit/d4aee57b8d7f71e23f0978165487f92b5085680a))

- Automate build and PyPI deployment
  ([`6c80188`](https://github.com/gasflux/gasflux/commit/6c8018846225f951320f4c9b166a75f4079fef85))

- Better grammar
  ([`cc65eef`](https://github.com/gasflux/gasflux/commit/cc65eef15102d5f171cb489c8027e0801f4766b8))

- Change altitude_ato to height_ato
  ([`34f4620`](https://github.com/gasflux/gasflux/commit/34f46201ce57a429b6060a09861a7c199a9db66c))

- Change height/altitude terminology
  ([`931cf28`](https://github.com/gasflux/gasflux/commit/931cf28537edf2e049a7ccc4839274707cb79db4))

- Colorscale updates
  ([`23575c9`](https://github.com/gasflux/gasflux/commit/23575c969dc444e7eddae21dabdcb59a636e2ff4))

- Drop geometry col from utm calc
  ([`06fa6a6`](https://github.com/gasflux/gasflux/commit/06fa6a6bffcb34c826b8528515567b2f2b133a47))

- Encoding for Windows
  ([`40c835a`](https://github.com/gasflux/gasflux/commit/40c835a65df139e31a7cb9431f54427f595497d8))

- Force patch update
  ([`4210be2`](https://github.com/gasflux/gasflux/commit/4210be2d05145094fc2139981dde882594eb4b2b))

- Function name in tests
  ([`5518c89`](https://github.com/gasflux/gasflux/commit/5518c89442aee1641fa9b98b22c3bf26c0560122))

- Plane_angle output in degrees
  ([`a1059b4`](https://github.com/gasflux/gasflux/commit/a1059b450823b1a6a586652f9ce17762f68b1ee9))

- Remove inaccurate language for heading
  ([`75556c3`](https://github.com/gasflux/gasflux/commit/75556c3ffa22c5480cc81c2bddc8fe0e0d3e6123))

- Safety, semver etc
  ([`7b534d7`](https://github.com/gasflux/gasflux/commit/7b534d7ee3bb087b07173e146686caf224f2a190))

- Time series baseline plot etc
  ([`35236ea`](https://github.com/gasflux/gasflux/commit/35236ea964c2f8d0989b9a9a24da2b106fea150c))

- Typos
  ([`9b45d17`](https://github.com/gasflux/gasflux/commit/9b45d17c27e79257ea085c767f444d28d87baf81))

- Update monotonic transect splitter
  ([`6395543`](https://github.com/gasflux/gasflux/commit/63955436eb1c70c41dd151e7efa072f9255e0065))

### Build System

- Update action names
  ([`5f1d22d`](https://github.com/gasflux/gasflux/commit/5f1d22d74ea1fc0a63c82013e8e0d230fda0c0d2))

### Features

- Add kwargs to baseline algorithm in config
  ([`91a9777`](https://github.com/gasflux/gasflux/commit/91a977766cc1efb9a15eb1c168494bbb24a79c48))

- Better cli config generation
  ([`daf75ec`](https://github.com/gasflux/gasflux/commit/daf75ecae7e2b02208129e949b49417aadcba764))

- Ground-level cut for kriging
  ([`853d1e4`](https://github.com/gasflux/gasflux/commit/853d1e446490a367c257d286eb0a2f85697fea5d))


## v0.1.2 (2024-04-14)

### Bug Fixes

- Adding data files
  ([`480429d`](https://github.com/gasflux/gasflux/commit/480429d72519d6a53262e4ebbe480548a9162a37))


## v0.1.1 (2024-04-14)

### Bug Fixes

- Add debug access
  ([`a842940`](https://github.com/gasflux/gasflux/commit/a84294001f22ab83915444c13d040adadb0fc777))

### Features

- Add version number to outputs
  ([`0b78052`](https://github.com/gasflux/gasflux/commit/0b78052c855e5bf08faa69ba80e512c100a4c833))

- Adding output dump
  ([`7fa52e8`](https://github.com/gasflux/gasflux/commit/7fa52e861db1877fc1f57073aa0e796338b63e68))

- Better CLI
  ([`9918e48`](https://github.com/gasflux/gasflux/commit/9918e4822b9f1fa4be702b82a4850d04824e0b12))

- Cli add
  ([`f018d1d`](https://github.com/gasflux/gasflux/commit/f018d1d761ae92c5e6c9f6f729bac4b57f7b7573))

- Remove long arrays from output
  ([`afe1617`](https://github.com/gasflux/gasflux/commit/afe1617401bb0a3f27900347642c80f969c4d504))
